==> sui-map-google-1.3.0.tgz: package/lib/image/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
var _excluded = ["alt", "apiKey", "center", "children", "height", "width"];
import PropTypes from 'prop-types';
import { toQueryString } from '@s-ui/js/lib/string';
import Injector from '@s-ui/react-primitive-injector';
import { BASE_URL, DEFAULT_CENTER, DEFAULT_CHILDREN_ALT, DEFAULT_HEIGHT, DEFAULT_WIDTH } from './config.js';
import { jsx as _jsx } from "react/jsx-runtime";

function MapGoogleImage(_ref) {
  var _ref$alt = _ref.alt,
      alt = _ref$alt === void 0 ? DEFAULT_CHILDREN_ALT : _ref$alt,
      apiKey = _ref.apiKey,
      _ref$center = _ref.center;
  _ref$center = _ref$center === void 0 ? DEFAULT_CENTER : _ref$center;

  var lat = _ref$center.lat,
      lng = _ref$center.lng,
      _ref$children = _ref.children,
      children = _ref$children === void 0 ? /*#__PURE__*/_jsx("img", {}) : _ref$children,
      _ref$height = _ref.height,
      height = _ref$height === void 0 ? DEFAULT_HEIGHT : _ref$height,
      _ref$width = _ref.width,
      width = _ref$width === void 0 ? DEFAULT_WIDTH : _ref$width,
      others = _objectWithoutPropertiesLoose(_ref, _excluded);

  var params = toQueryString(_extends({}, others, {
    key: apiKey,
    center: lat + "," + lng
  }));
  var src = BASE_URL + "?" + params;
  return /*#__PURE__*/_jsx(Injector, {
    src: src,
    alt: alt,
    width: width,
    height: height,
    children: children
  });
}

MapGoogleImage.displayName = 'MapGoogleImage';
export default MapGoogleImage;

==> sui-map-google-1.4.0.tgz: package/lib/image/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
var _excluded = ["alt", "apiKey", "center", "children", "height", "size", "width"];
import PropTypes from 'prop-types';
import { toQueryString } from '@s-ui/js/lib/string';
import Injector from '@s-ui/react-primitive-injector';
import { BASE_URL, DEFAULT_CENTER, DEFAULT_CHILDREN_ALT } from './config.js';
import { jsx as _jsx } from "react/jsx-runtime";

function MapGoogleImage(_ref) {
  var _ref$alt = _ref.alt,
      alt = _ref$alt === void 0 ? DEFAULT_CHILDREN_ALT : _ref$alt,
      apiKey = _ref.apiKey,
      _ref$center = _ref.center;
  _ref$center = _ref$center === void 0 ? DEFAULT_CENTER : _ref$center;

  var lat = _ref$center.lat,
      lng = _ref$center.lng,
      _ref$children = _ref.children,
      children = _ref$children === void 0 ? /*#__PURE__*/_jsx("img", {}) : _ref$children,
      height = _ref.height,
      size = _ref.size,
      width = _ref.width,
      others = _objectWithoutPropertiesLoose(_ref, _excluded);

  if (!height || !width) {
    throw new Error('Height and Width are mandatory in static map');
  }

  var params = toQueryString(_extends({}, others, {
    key: apiKey,
    center: lat + "," + lng,
    size: size != null ? size : width + "x" + height
  }));
  var src = BASE_URL + "?" + params;
  return /*#__PURE__*/_jsx(Injector, {
    src: src,
    alt: alt,
    width: width,
    height: height,
    children: children
  });
}

MapGoogleImage.displayName = 'MapGoogleImage';
export default MapGoogleImage;
